* code for (approximately) replicating Cook and Durance (2013), used in Roodman (2015)

set varabbrev off

global crimes Violent Murder Rape Assault Robbery Property Burglary Larceny Vehicle
global CODs DeathsInj DeathsHom DeathsSui DeathsTraf // causes of death

**** Prepare data

* odbc load, clear dsn("Sin taxes") exec("select * from [U.S. state panel]")
use "US state panel", clear
gen double CxPop = (BeerCx+WineCx+SpirCx) / Pop14NIAAA
replace CxPop = . if Year==1990 | Year==1991 // consumption data for both years distorted by arrival of tax
tsset FIPS Year
xi i.Year
foreach outcome in $CODs {
	gen double  `outcome'Pop = `outcome'CDC / PopCDC * 100000
	gen double D`outcome'Pop = 100*(`outcome'Pop/L.`outcome'Pop - 1)
}
foreach outcome in $crimes {
	ren `outcome'PopUCR `outcome'Pop // for replication use Uniform Crime Reporting-computed rates even though heavily rounded, creating imprecision in differences
	gen double D`outcome'Pop = 100*(`outcome'Pop/L.`outcome'Pop - 1)
}
gen double DCxPop = F.CxPop - L2.CxPop // three years to leap over 1990-91

**** Tables 2 & 3

gen double C89 = cL2.CxPop#1991.Year // main regressor: 1989-91 consumption change
outreg, clear(Results)
foreach outcomeset in Cx "$CODs" "$crimes" { // "Panel II no FE" regressions not reported: help bracket any dynamic panel bias
	foreach outcome in `outcomeset' {
		regress D`outcome'Pop L2.CxPop             if Year==1991             & Cook_Durance_sample, robust
		outreg, keep(L2.CxPop) rtitle("`:subinstr local outcome "_" " ", all'") ctitle("", "Cross-section") noauto starlevels(10 5 1) nodisplay tdec(3) se
		xtreg   D`outcome'Pop C89          _IYear* if Year>1985 & Year<=1995 & Cook_Durance_sample, robust fe
		outreg, keep(C89)               rtitle("`:subinstr local outcome "_" " ", all'") ctitle("", "Panel I" ) merge noauto starlevels(10 5 1) nodisplay tdec(3) se
		xtreg   D`outcome'Pop C89 L2.CxPop _IYear* if Year>1985 & Year<=1995 & Cook_Durance_sample, robust fe
		outreg, keep(C89)               rtitle("`:subinstr local outcome "_" " ", all'") ctitle("", "Panel II") merge noauto starlevels(10 5 1) nodisplay tdec(3) se
		reg     D`outcome'Pop C89 L2.CxPop _IYear* if Year>1985 & Year<=1995 & Cook_Durance_sample, robust // not reported. With- and without-FE estimates should bracket true values
		outreg, keep(C89)               rtitle("`:subinstr local outcome "_" " ", all'") ctitle("", "Panel II no FE") merge noauto starlevels(10 5 1) nodisplay tdec(3) se store(newrow)
		capture outreg, store(Results) nodisplay replay(Results) append(newrow)
		if _rc  outreg, store(Results) nodisplay replay
	}
}
outreg using "Cook & Durance", replay(Results) replace


**** Falsification test graphs

* Rebuild variables using same population denominators. Makes crime variables more precise.
use "US state panel", clear
gen double CxPop = (BeerCx+WineCx+SpirCx) / Pop14
replace CxPop = . if Year==1990 | Year==1991
tsset FIPS Year
xi i.Year

foreach outcome in $CODs $crimes {
	gen double `outcome'Pop = `outcome' / Pop * 100000
	gen double D`outcome'Pop = 100*(`outcome'Pop/L.`outcome'Pop - 1)
}
gen DCxPop = F.CxPop - L2.CxPop // three years to leap over 1990-91

foreach outcomeset in Cx "$CODs" "$crimes" {
	foreach outcome in `outcomeset' {
		cap mat drop Results
		foreach year of numlist 1987/1991 1994/1995 {
			cap xtreg D`outcome'Pop cL2.CxPop#`year'.Year L2.CxPop _IYear* if Cook_Durance_sample, robust fe
			if !_rc mat Results = nullmat(Results) \ (`year', _b[cL2.CxPop#`year'.Year], _se[cL2.CxPop#`year'.Year])
		}
		mat colnames Results = Year b se
		cap drop Results*
		svmat Results, names(matcol)
		cap drop lo hi
		qui gen hi = Resultsb+1.96*Resultsse
		qui gen lo = Resultsb-1.96*Resultsse
		twoway rspike lo hi ResultsYear || scatter Resultsb ResultsYear, name(`outcome', replace) title(`:subinstr local outcome "_" " ", all') legend(off) xtitle("") nodraw scheme(s1mono)
	}
}
graph combine $CODs $crimes, xcommon cols(4) xsize(6.5) ysize(5) scheme(s1mono)
