* code to (approximately) replicate Florida, Alaska, abd Illinois alcohol tax impact studies, as used in Roodman (2015)

* program to prepare data set
* [if] controls sample
* state() is state of interest
* pop() is population denominator variable for death rates
* [m] [q] indicate using monthly or quarterly data
cap program drop PrepData
program define PrepData
	version 11
*	odbc load, clear dsn("Sin taxes") exec("select * from [U.S. state month panel]")
	use "US state month panel.dta", clear

	syntax [if], state(string) pop(string) [m] [q]
	local mq `m'`q'
	if `"`if'"'!="" keep `if'

	// collapse to one obs per month and state of interest vs. rest
	replace PersInc = PersInc / Pop
	gen byte D = Postal_code!="`state'"
	gen long PopGonorrhea = cond(Gonorrhea>0 & Gonorrhea<., `pop', 0)
	gen long PopChlamydia = cond(Chlamydia>0 & Chlamydia<., `pop', 0)
	collapse CPI PersInc MedInc (sum) Deaths DeathsAlc DeathsAlcCirr DeathsAlcWM DeathsAlcCause DeathsAlcCauseWM Gonorrhea Chlamydia `pop' PopGonorrhea PopChlamydia, by(Year Month D)

	if "`m'"!="" {
		local freq 12
		local MonthQuarter Month
	}
	else {
		local freq 4
		local MonthQuarter Quarter
		gen byte Quarter = floor((Month+2)/3)
		collapse CPI PersInc MedInc `pop' PopGonorrhea PopChlamydia (sum) Deaths DeathsAlc DeathsAlcCirr DeathsAlcWM DeathsAlcCause DeathsAlcCauseWM Gonorrhea Chlamydia, by(Year Quarter D)
	}

	recode *WM (0 = .) if Year<1968
	recode Deaths* (0 = .) if Year>2004
	recode Pop* (0 = .) if Year<1969
	recode Chlamydia Gonorrhea (0 = .)

	gen DeathsNonalc   = Deaths - DeathsAlc
	gen DeathsNonalcWM = Deaths - DeathsAlcWM

	gen int t`mq' = (Year-1960)*`freq' + `MonthQuarter' - 1
	tsset D t`mq'
	format t`mq' %t`mq'

	// interpolate variables
	foreach var in `pop' PopGonorrhea PopChlamydia MedInc {
		replace `var' =. if `MonthQuarter'!=`freq'/2 // interpolate an annual variable
		by D: ipolate `var' t`mq', gen(t) epolate
		replace `var' = (t + F.t)/2
		drop t
		replace `var' = L.`var' + LD.`var' if `var'==.
	}

	if "`m'"!="" {
		replace PersInc =. if !inlist(Month,2,5,8,11) // interpolate PersInc, a quarterly variable
		by D: ipolate PersInc tm, gen(t) epolate
		replace PersInc = t
		drop t
	}
	
	foreach var of varlist Deaths* {
		gen double `var'Pop = `var' / `pop' * 100000
	}
	gen double GonorrheaPop = Gonorrhea / PopGonorrhea * 1e5
	gen double ChlamydiaPop = Chlamydia / PopChlamydia * 1e5
	drop Deaths DeathsPop PopGonorrhea PopChlamydia

	// make time series data set
	reshape wide Deaths* Gonorrhea* Chlamydia* PersInc MedInc `pop', i(Year `MonthQuarter' t`mq') j(D)
	drop PersInc1 MedInc1 DeathsNonalcPop1 DeathsNonalc1 DeathsNonalcWMPop1 DeathsNonalcWM1 `pop'1
	tsset t`mq'
	foreach var in PersInc MedInc DeathsAlc DeathsAlcCirr DeathsNonalc DeathsAlcPop DeathsAlcCirrPop DeathsNonalcPop DeathsAlcWM DeathsNonalcWM DeathsAlcWMPop DeathsNonalcWMPop DeathsAlcCause DeathsAlcCauseWM DeathsAlcCausePop DeathsAlcCauseWMPop Gonorrhea Chlamydia GonorrheaPop ChlamydiaPop `pop' {
		ren `var'0 `var'
	}
	foreach var in DeathsAlc DeathsAlcPop DeathsAlcWM DeathsAlcWMPop DeathsAlcCirr DeathsAlcCirrPop  DeathsAlcCause DeathsAlcCauseWM DeathsAlcCausePop DeathsAlcCauseWMPop Gonorrhea Chlamydia GonorrheaPop ChlamydiaPop {	
		ren `var'1 `var'Rest
	}

	gen PersIncReal = PersInc / CPI * 214.537
	gen MedIncReal  = MedInc / CPI * 214.537
	foreach var in PersIncReal MedIncReal DeathsAlcWMPop DeathsAlcPop DeathsNonalcWMPop DeathsAlcWMPopRest DeathsNonalcPop DeathsAlcPopRest DeathsAlcCirrPop DeathsAlcCirrPopRest DeathsAlcCausePop DeathsAlcCauseWMPop DeathsAlcCausePopRest DeathsAlcCauseWMPopRest {
		gen double l`var' = ln(`var')
	}

	label var DeathsAlcPop       "Deaths per 100,000 population"
	label var DeathsAlcPopRest   "Deaths per 100,000 population"
	label var DeathsAlcWMPop     "Deaths per 100,000 population"
	label var DeathsAlcWMPopRest "Deaths per 100,000 population"
end


******
****** Florida (Maldonado-Molina and Wagenaar 2009)
******

PrepData if !inlist(Postal_code,"HI","AK","DC"), state(FL) pop(Pop15) m // sample is continental 48; population denominator is age>=15; monthly data
gen double BeerTx = cond(tm<tm(1977m7),  .32, cond(tm<tm(1983m9),  .4 ,  .48)) // nominal tax values
gen double WineTx = cond(tm<tm(1977m7), 1.15, cond(tm<tm(1983m9), 1.75, 2.25))
gen double SpirTx = cond(tm<tm(1977m7), 3.75, cond(tm<tm(1983m9), 4.75, 6.5 ))
foreach beverage in Beer Wine Spir {
	gen double `beverage'TxReal = `beverage'Tx / CPI * 214.537 // 2009 $
	gen double l`beverage'TxReal = ln(`beverage'TxReal)
}

tsline DeathsAlcWMPop if Year>=1969 & Year<=2004, ylab(0/4) tlab(, format(%tmCCYY)) xtitle("") name(FL, replace) tline(1977m7 1983m9) // Figure 1A
tsline DeathsAlcWMPopRest if Year>=1969 & Year<=2004, ylab(0/4) tlab(, format(%tmCCYY)) xtitle("") name(rest, replace)  // Figure 1B
tsline DeathsAlcWMPop if Year>=1969 & Year<=2004, ylab(2/4) tlab(, format(%tmCCYY)) xtitle("") lwidth(thin) tline(1977m7 1983m9) /// // for Roodman write-up
	ttext(2.25 1977m7 "Tax increase" "July 1977", place(w) just(right) size(small) margin(small)) ///
	ttext(2.25 1983m9 "Tax increase" "September 1983", place(w) just(right) size(small) margin(small)) ///
	ytitle("Deaths per 100,000 people age {&ge}15") ///
	xsize(6.25) ysize(4) scheme(s1mono)

* ARIMA models (corresponding to Maldonado-Molina and Wagenaar Table 3; Roodman results table)
arima DeathsAlcWM       BeerTxReal lPersIncReal  DeathsNonalcWM     DeathsAlcWMRest   , arima(0,1,1) sarima(0,1,1,12) // raw frequency
arima DeathsAlcWMPop    BeerTxReal lPersIncReal  DeathsNonalcWMPop  DeathsAlcWMPopRest, arima(0,1,1) sarima(0,1,1,12) // Rate per 100K population
arima lDeathsAlcWMPop  lBeerTxReal lPersIncReal lDeathsNonalcWMPop lDeathsAlcWMPopRest, arima(0,1,1) sarima(0,1,1,12) // Elasticity

* same, but include ICD-8 code 303.9 for 1969-1978 (Roodman results table)
arima DeathsAlc       BeerTxReal lPersIncReal  DeathsNonalc     DeathsAlcRest   , arima(0,1,1) sarima(0,1,1,12) // raw frequency
arima DeathsAlcPop    BeerTxReal lPersIncReal  DeathsNonalcPop  DeathsAlcPopRest, arima(0,1,1) sarima(0,1,1,12) // Rate per 100K population
arima lDeathsAlcPop  lBeerTxReal lPersIncReal lDeathsNonalcPop lDeathsAlcPopRest, arima(0,1,1) sarima(0,1,1,12) // Elasticity

* Fixed effects model (Table 4, row 2)? (not reported in Roodman)
xi i.Month
arima lDeathsAlcWMPop  lBeerTxReal lPersIncReal lDeathsNonalcWMPop lDeathsAlcWMPopRest _IMonth*, ar(1)

* regress on tax change dummies instead of tax--as is standard in interrupted time series analysis (not reported in Roodman)
gen byte D1977m7 = tm>=tm(1977m7)
gen byte D1983m9 = tm>=tm(1983m9)
arima DeathsAlcPop D1977m7 D1983m9 lPersIncReal DeathsNonalcPop DeathsAlcPopRest, arima(0,1,1) sarima(0,1,1,12) 

 * falsification test: regress on post-t0 dummy instead of beer tax, where t0 ranges across sample
PrepData if Postal_code!="HI" & Postal_code!="AK", pop(Pop15) state(FL) m
foreach var in Alc AlcCirr { // "Alc"->DeathsAlc, alcohol-related deaths--used in Roodman text
	cap postclose falspost
	postfile falspost t0 ll b se using falspostFL`var', every(1) replace
	forvalues t0=`=tm(1970m1)'/`=tm(2004m12)' {
		cap drop D
		gen byte D = tm>=`t0'
		qui arima lDeaths`var'Pop D lPersIncReal lDeathsNonalcPop lDeaths`var'PopRest, arima(0,1,1) sarima(0,1,1,12) `=cond(`t0'>tm(1970m1),"from(b)","")'
		post falspost (`t0') (`e(ll)') (`=_b[DS12.D]')  (`=_se[DS12.D]')
		noi di "(`t0') (`e(ll)') (`=_b[DS12.D]')  (`=_se[DS12.D]')"
		mat b=e(b)
	}
	arima lDeaths`var'Pop lPersIncReal lDeathsNonalcPop lDeaths`var'PopRest, arima(0,1,1) sarima(0,1,1,12)
	scalar ll0 = e(ll)
	postclose falspost
	preserve
	use falspostFL`var', clear
	format t0 %tm
	tsset t0
	replace b = b * 100 // express as %
	replace se = se * 100
	gen lo_wald = b - 1.96*se
	gen hi_wald = b + 1.96*se
	twoway rarea hi_wald lo_wald t0 if t0<tm(2004m1) || tsline b, tline(1977m7 1983m9) /// // Wald-based standard errors
		legend(off) xlab(, format(%tmCCYY)) ttitle("") name(false`var', replace) tmtick(1969m1(12)2004m1, grid) scheme(s1mono) ytick(-20(10)20, grid) xsize(6.25) ysize(4) ytitle("Unpredicted % change in deaths per person age {&ge}15")
	restore
}

* Florida, with Alaska specification--quarterly instead of monthly, tax change dummies instead of beer tax rate, no control for non-alcohol-related deaths (not reported in Roodman)
PrepData if Postal_code!="HI" & Postal_code!="AK", state(FL) pop(Pop15) q
gen byte D1 = tq>=tq(1977q3)
gen byte D2 = tq>=tq(1983q4)
arima DeathsAlc     D1 D2  DeathsAlcRest   , arima(0,1,1) sarima(0,1,1,4) // raw frequency
arima DeathsAlcPop  D1 D2  DeathsAlcPopRest, arima(0,1,1) sarima(0,1,1,4) // Rate per 100K population
arima lDeathsAlcPop D1 D2 lDeathsAlcPopRest, arima(0,1,1) sarima(0,1,1,4) // Elasticity


******
****** Alaska (Wagenaar, Maldonado-Molina, and Wagenaar 2009)
******

PrepData if Year>=1976, state(AK) pop(Pop15) q
gen byte D1 = tq>=tq(1983q3)
gen byte D2 = tq>=tq(2002q4)
replace DeathsAlcWMPop = DeathsAlcWMPop / DeathsAlcWM * 36 if Year==2003 & Quarter==2 // the one data mismatch I have not explained
replace DeathsAlcWM = 36 if Year==2003 & Quarter==2
replace lDeathsAlcWMPop = ln(DeathsAlcWMPop)

* Wagenaar, Maldonado-Molina, and Wagenaar Figures 2 & 3
scatter DeathsAlcWM    tq if Year<=2004, tlab(, format(%tqCCYY)) ttitle("") tline(1983q3 2002q4) ylab(0(10)60) name(AKdeaths, replace) msize(small)
scatter DeathsAlcWMPop tq if Year<=2004, tlab(, format(%tqCCYY)) ttitle("") tline(1983q3 2002q4) ylab(0(2 )12) name(AKdeathspop, replace) msize(small)

* ARIMA models (corresponding to Wagenaar, Maldonado-Molina, and Wagenaar Table 1; Roodman results table) 
arima DeathsAlcWM    D1 D2, arima(0,1,1) sarima(0,1,1,4)
arima DeathsAlcWMPop D1 D2, arima(0,1,1) sarima(0,1,1,4)
arima DeathsAlcWMPop D1 D2 DeathsAlcWMPopRest, arima(0,1,1) sarima(0,1,1,4)
arima lDeathsAlcWMPop D1 D2 lDeathsAlcWMPopRest, arima(0,1,1) sarima(0,1,1,4)

* same, but corrected death variables pre-1979 (Roodman results table)
arima  DeathsAlc    D1 D2                  , arima(0,1,1) sarima(0,1,1,4) // this change knocks out the first dummy
arima  DeathsAlcPop D1 D2                  , arima(0,1,1) sarima(0,1,1,4)
arima  DeathsAlcPop D1 D2  DeathsAlcPopRest, arima(0,1,1) sarima(0,1,1,4)
arima lDeathsAlcPop D1 D2 lDeathsAlcPopRest, arima(0,1,1) sarima(0,1,1,4)

* Table 1, second panel (alcohol-caused only), corrected death variables pre-1979. Used for AK 2002 impact coefficient in final table of Roodman
arima lDeathsAlcCausePop D1 D2 lDeathsAlcPopRest, arima(0,1,1) sarima(0,1,1,4)

* falsification test: regress on post-t0 dummy, where t0 ranges across sample
PrepData if Year>=1969, state(AK) pop(Pop15) q // 1969-2004, same as Florida
xi i.Quarter
foreach var in Alc AlcCirr { // "Alc"->DeathsAlc, alcohol-related deaths--used in Roodman text
	cap postclose falspost
	postfile falspost t0 ll b se using falspostAK`var', every(1) replace
	forvalues t0=`=tq(1970q4)'/`=tq(2004q4)' {
		cap drop D
		gen byte D = tq>=`t0'
		qui arima lDeaths`var'Pop D lDeaths`var'PopRest, arima(0,1,1) sarima(0,1,1,4)
		post falspost (`t0') (`e(ll)') (`=_b[DS4.D]') (`=_se[DS4.D]')
		noi di "(`t0') (`e(ll)') (`=_b[DS4.D]') (`=_se[DS4.D]')"
	}
	postclose falspost
	arima Deaths`var'Pop Deaths`var'PopRest, arima(0,1,1) sarima(0,1,1,4)
	preserve
	use falspostAK`var', clear
	format t0 %tq
	tsset t0
	replace b = b * 100 // express as %
	replace se = se * 100
	gen lo = b - 1.96*se
	gen hi = b + 1.96*se
	twoway rarea hi lo t0 || tsline b, ///
		tline(1983q3 2002q4) tlab(, format(%tqCCYY)) legend(off) ttitle("")  ytitle("Unpredicted % change in deaths per person age {&ge}15") ///
		tmtick(1970q1(4)2005q1, grid) name(false`var', replace) ytick(-100(50)100, grid) xsize(6.25) ysize(4) scheme(s1mono) || if t0<tq(2004q1)
	restore
}


******
****** Illinois STDs (Staras et al. 2014)
******

PrepData if Year>=1995 & (Staras_et_al_control_group | Postal_code=="IL"), state(IL) pop(Pop) m // STD "Rest" vars wrong before 2003 because numerator missing states but not denominator
gen byte D0 = tm==tm(2007m12) // weird data that month
gen byte D1 = tm>=tm(2009m9)

* Staras et al. Table 1? (Roodman results table)
newey GonorrheaPop D1 GonorrheaPopRest MedIncReal D0 if tin(2003m1, 2011m12), lag(12)
newey ChlamydiaPop D1 ChlamydiaPopRest MedIncReal if tin(2003m1, 2011m12), lag(12)

* drop suspect post-2009 data (Roodman results table)
newey GonorrheaPop D1 GonorrheaPopRest MedIncReal D0 if tin(2003m1, 2009m12), lag(12)
newey ChlamydiaPop D1 ChlamydiaPopRest MedIncReal D0 if tin(2003m1, 2009m12), lag(12)

* Wagenaar-style ARIMA analogs (Roodman results table)
arima GonorrheaPop D1 GonorrheaPopRest MedIncReal D0 if tin(2003m1, 2009m12), arima(0,1,1) sarima(0,1,1,12)
arima ChlamydiaPop D1 ChlamydiaPopRest MedIncReal D0 if tin(2003m1, 2009m12), arima(0,1,1) sarima(0,1,1,12)

* Impact on STDs in Alaska
* Nationally in 2002, STD data missing only Arizona; less complete before that. So start sample in 2002.
PrepData if (Postal_code=="AK" | Staras_et_al_control_group), state(AK) pop(Pop) m
gen byte D = tm>=tm(2002m10)
arima GonorrheaPop D GonorrheaPopRest lMedIncReal if tin(2002m1, 2100m1), arima(0,1,1) sarima(0,1,1,12) // nothing
arima ChlamydiaPop D ChlamydiaPopRest lMedIncReal if tin(2002m1, 2100m1), arima(0,1,1) sarima(0,1,1,12) // nothing
